Learn R Programming

dynsurv (version 0.2-2)

coef.bayesCox: Extract Coefficients from Bayesian Cox Model

Description

Extract coefficient values from bayesCox fitting results, and summarize the posterior mean, posterior 2.5% and 97.5% quantiles into a data frame.

Usage

"coef"(object, ...)

Arguments

object
an object returned by function bayesCox.
...
other arguments.

Value

A data.frame with 6 columns ("Low", "Mid", "High", "Time", "Cov", "Model"), where "Low" and "High" are the posterior 2.5% and 97.5% quantiles; "Mid" is the posterior mean; "Cov" and "Model" contain character values of the covariates and model types.

See Also

bayesCox, and plotCoef.

Examples

Run this code
# See the examples in bayesCox

Run the code above in your browser using DataLab