Learn R Programming

dynsurv (version 0.2-2)

coef.splineCox: Extract Coefficients from Spline Base Cox Model

Description

Extract coefficient values from splineCox fitting results, and summarize the point estimate and 95% confidence band into a data frame.

Usage

"coef"(object, ...)

Arguments

object
an object returned by function splineCox.
...
other arguments.

Value

A data.frame with 6 columns ("Low", "Mid", "High", "Time", "Cov", "Model"), where "Mid" is the point estimates; "Low" and "High" are the point estimates plus and minus 1.96 times standard deviations; "Cov" and "Model" contain character values of the covariates and model type.

See Also

splineCox, and plotCoef.

Examples

Run this code
# See the examples in splineCox

Run the code above in your browser using DataLab