Learn R Programming

dynsurv (version 0.2-2)

coef.tvTran: Extract Coefficients from Time-varying Transformation Model

Description

Extract coefficient values from tvTran fitting results, and summarize the point estimate and 95% confidence band into a data frame.

Usage

"coef"(object, ...)

Arguments

object
an object returned by function tvTran.
...
other arguments.

Value

A data.frame with 6 columns ("Low", "Mid", "High", "Time", "Cov", "Model"), where "Mid" is the point estimates; "Low" and "High" are the 2.5% and 97.5% quantiles estimates from resampling method; "Cov" and "Model" contain character values of the covariates and model type.

See Also

tvTran, and plotCoef.

Examples

Run this code
# See the examples in tvTran

Run the code above in your browser using DataLab