Learn R Programming

dynsurv (version 0.2-2)

nu.bayesCox: Extract Latent Variance from Bayesian Cox Model

Description

Extract latent variance from bayesCox fitting results, and summarize them into a data frame. It is applicable when model="TimeVarying" or model="Dynamic", and coef.prior=list(type="HAR1").

Usage

"nu"(object, ...)

Arguments

object
an object returned by function bayesCox.
...
other arguments.

Value

A data.frame with 4 columns ("Iter", "Model", "Cov", "Value"), where Iter is the iteration number; Model and Cov contain the character values of the model type and covariates.

See Also

bayesCox, and plotNu.

Examples

Run this code
# See the examples in bayesCox

Run the code above in your browser using DataLab